@@ -66,22 +66,9 @@ bool runWebFilesMoverScript(RclConfig *config)
             downloadsdir = path_tildexpand("~/Downloads");
         }
     }
-    static string cmdpath;
-    vector<string> args;
-#ifdef _WIN32
-    const static string cmdnm{"python"};
-    args.push_back(config->findFilter("recoll-we-move-files.py"));
-#else
-    const static string cmdnm{"recoll-we-move-files.py"};
-#endif
-    if (cmdpath.empty()) {
-        cmdpath = config->findFilter(cmdnm);
-        if (cmdpath.empty()) {
-            LOGERR("runWFMoverScript: recoll-we-move-files.py not found\n");
-            return false;
-        }
-    }
-
+    vector<string> cmdvec;
+    config->pythonCmd("recoll-we-move-files.py", cmdvec);
+    
     /* Arrange to not actually run the script if the directory did not change */
     static time_t dirmtime;
     time_t ndirmtime = 0;
@@ -100,7 +87,7 @@ bool runWebFilesMoverScript(RclConfig *config)
            are created during the run. */
         dirmtime = ndirmtime;
         ExecCmd cmd;
-        int status = cmd.doexec(cmdpath, args);
+        int status = cmd.doexec1(cmdvec);
         return status == 0;
     }
     return true;
@@ -117,9 +104,9 @@ ConfIndexer::ConfIndexer(RclConfig *cnf, DbIxStatusUpdater *updfunc)
 
 ConfIndexer::~ConfIndexer()
 {
-     deleteZ(m_fsindexer);
+    deleteZ(m_fsindexer);
 #ifndef DISABLE_WEB_INDEXER
-     deleteZ(m_webindexer);
+    deleteZ(m_webindexer);
 #endif
 }
 
@@ -132,14 +119,14 @@ bool ConfIndexer::runFirstIndexing()
 {
     // Indexing status file existing and not empty ?
     if (path_filesize(m_config->getIdxStatusFile()) > 0) {
-    LOGDEB0("ConfIndexer::runFirstIndexing: no: status file not empty\n");
-    return false;
+        LOGDEB0("ConfIndexer::runFirstIndexing: no: status file not empty\n");
+        return false;
     }
     // And only do this if the user has kept the default topdirs (~). 
     vector<string> tdl = m_config->getTopdirs();
     if (tdl.size() != 1 || tdl[0].compare(path_canon(path_tildexpand("~")))) {
-    LOGDEB0("ConfIndexer::runFirstIndexing: no: not home only\n");
-    return false;
+        LOGDEB0("ConfIndexer::runFirstIndexing: no: not home only\n");
+        return false;
     }
     return true;
 }
@@ -150,7 +137,7 @@ bool ConfIndexer::firstFsIndexingSequence()
     deleteZ(m_fsindexer);
     m_fsindexer = new FsIndexer(m_config, &m_db, m_updater);
     if (!m_fsindexer) {
-    return false;
+        return false;
     }
     int flushmb = m_db.getFlushMb();
     m_db.setFlushMb(2);
@@ -164,26 +151,33 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
 {
     Rcl::Db::OpenMode mode = resetbefore ? Rcl::Db::DbTrunc : Rcl::Db::DbUpd;
     if (!m_db.open(mode)) {
-    LOGERR("ConfIndexer: error opening database " << m_config->getDbDir() <<
+        LOGERR("ConfIndexer: error opening database " << m_config->getDbDir() <<
                " : " << m_db.getReason() << "\n");
         addIdxReason("indexer", m_db.getReason());
-    return false;
+        return false;
     }
-
+    std::string logloc;
+    if (Logger::getTheLog()->logisstderr()) {
+        logloc = "program error output.";
+    } else {
+        logloc = std::string(" log in ") +
+            Logger::getTheLog()->getlogfilename() + ".";
+    }
+    
     m_config->setKeyDir(cstr_null);
     if (typestorun & IxTFs) {
-    if (runFirstIndexing()) {
-        firstFsIndexingSequence();
-    }
+        if (runFirstIndexing()) {
+            firstFsIndexingSequence();
+        }
         deleteZ(m_fsindexer);
         m_fsindexer = new FsIndexer(m_config, &m_db, m_updater);
         if (!m_fsindexer || !m_fsindexer->index(flags)) {
             if (stopindexing) {
                 addIdxReason("indexer", "Indexing was interrupted.");
             } else {
-                addIdxReason("indexer", "Index creation failed. See log.");
+                addIdxReason("indexer", "Index creation failed. See" + logloc);
             }
-        m_db.close();
+            m_db.close();
             return false;
         }
     }
@@ -193,8 +187,8 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
         deleteZ(m_webindexer);
         m_webindexer = new WebQueueIndexer(m_config, &m_db, m_updater);
         if (!m_webindexer || !m_webindexer->index()) {
-        m_db.close();
-            addIdxReason("indexer", "Web index creation failed. See log");
+            m_db.close();
+            addIdxReason("indexer", "Web index creation failed. See" + logloc);
             return false;
         }
     }
@@ -203,10 +197,10 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
         // Get rid of all database entries that don't exist in the
         // filesystem anymore. Only if all *configured* indexers ran.
         if (m_updater && !m_updater->update(DbIxStatus::DBIXS_PURGE, "")) {
-        m_db.close();
-            addIdxReason("indexer", "Index purge failed. See log");
-        return false;
-    }
+            m_db.close();
+            addIdxReason("indexer", "Index purge failed. See" + logloc);
+            return false;
+        }
         m_db.purge();
     }
 
@@ -214,22 +208,22 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
     // here. Makes no sense to check for cancel, we'll have to close
     // anyway
     if (m_updater)
-    m_updater->update(DbIxStatus::DBIXS_CLOSING, string());
+        m_updater->update(DbIxStatus::DBIXS_CLOSING, string());
     if (!m_db.close()) {
-    LOGERR("ConfIndexer::index: error closing database in " <<
+        LOGERR("ConfIndexer::index: error closing database in " <<
                m_config->getDbDir() << "\n");
-        addIdxReason("indexer", "Index close/flush failed. See log");
-    return false;
+        addIdxReason("indexer", "Index close/flush failed. See" +logloc);
+        return false;
     }
 
     if (m_updater && !m_updater->update(DbIxStatus::DBIXS_CLOSING, string()))
-    return false;
+        return false;
     bool ret = true;
     if (!createStemmingDatabases()) {
-    ret = false;
+        ret = false;
     }
     if (m_updater && !m_updater->update(DbIxStatus::DBIXS_CLOSING, string()))
-    return false;
+        return false;
 
     // Don't fail indexing because of an aspell issue: we ignore the status.
     // Messages were written to the reasons output
@@ -237,7 +231,7 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
     
     clearMimeHandlerCache();
     if (m_updater)
-    m_updater->update(DbIxStatus::DBIXS_DONE, string());
+        m_updater->update(DbIxStatus::DBIXS_DONE, string());
     return ret;
 }
 
@@ -246,14 +240,14 @@ bool ConfIndexer::indexFiles(list<string>& ifiles, int flag)
     list<string> myfiles;
     string origcwd = m_config->getOrigCwd();
     for (const auto& entry : ifiles) {
-    myfiles.push_back(path_canon(entry, &origcwd));
+        myfiles.push_back(path_canon(entry, &origcwd));
     }
     myfiles.sort();
 
     if (!m_db.open(Rcl::Db::DbUpd)) {
-    LOGERR("ConfIndexer: indexFiles error opening database " <<
+        LOGERR("ConfIndexer: indexFiles error opening database " <<
                m_config->getDbDir() << "\n");
-    return false;
+        return false;
     }
     m_config->setKeyDir(cstr_null);
     bool ret = false;
@@ -280,9 +274,9 @@ bool ConfIndexer::indexFiles(list<string>& ifiles, int flag)
     }
     // The close would be done in our destructor, but we want status here
     if (!m_db.close()) {
-    LOGERR("ConfIndexer::index: error closing database in " <<
+        LOGERR("ConfIndexer::index: error closing database in " <<
                m_config->getDbDir() << "\n");
-    return false;
+        return false;
     }
     ifiles = myfiles;
     clearMimeHandlerCache();
@@ -297,7 +291,7 @@ bool ConfIndexer::updateDocs(vector<Rcl::Doc> &docs, IxFlag flag)
     docsToPaths(docs, paths);
     list<string> files(paths.begin(), paths.end());
     if (!files.empty()) {
-    return indexFiles(files, flag);
+        return indexFiles(files, flag);
     }
     return true;
 }
@@ -307,14 +301,14 @@ bool ConfIndexer::purgeFiles(list<string> &files, int flag)
     list<string> myfiles;
     string origcwd = m_config->getOrigCwd();
     for (const auto& entry : files) {
-    myfiles.push_back(path_canon(entry, &origcwd));
+        myfiles.push_back(path_canon(entry, &origcwd));
     }
     myfiles.sort();
 
     if (!m_db.open(Rcl::Db::DbUpd)) {
-    LOGERR("ConfIndexer: purgeFiles error opening database " <<
+        LOGERR("ConfIndexer: purgeFiles error opening database " <<
                m_config->getDbDir() << "\n");
-    return false;
+        return false;
     }
     bool ret = false;
     m_config->setKeyDir(cstr_null);
@@ -337,9 +331,9 @@ bool ConfIndexer::purgeFiles(list<string> &files, int flag)
 
     // The close would be done in our destructor, but we want status here
     if (!m_db.close()) {
-    LOGERR("ConfIndexer::purgefiles: error closing database in " <<
+        LOGERR("ConfIndexer::purgefiles: error closing database in " <<
                m_config->getDbDir() << "\n");
-    return false;
+        return false;
     }
     return ret;
 }
@@ -356,18 +350,18 @@ bool ConfIndexer::createStemmingDatabases()
             addIdxReason("stemming", "could not open db");
             return false;
         }
-    vector<string> langs;
-    stringToStrings(slangs, langs);
+        vector<string> langs;
+        stringToStrings(slangs, langs);
 
-    // Get the list of existing stem dbs from the database (some may have 
-    // been manually created, we just keep those from the config
-    vector<string> dblangs = m_db.getStemLangs();
-    vector<string>::const_iterator it;
-    for (it = dblangs.begin(); it != dblangs.end(); it++) {
-        if (find(langs.begin(), langs.end(), *it) == langs.end())
-        m_db.deleteStemDb(*it);
-    }
-    ret = ret && m_db.createStemDbs(langs);
+        // Get the list of existing stem dbs from the database (some may have 
+        // been manually created, we just keep those from the config
+        vector<string> dblangs = m_db.getStemLangs();
+        vector<string>::const_iterator it;
+        for (it = dblangs.begin(); it != dblangs.end(); it++) {
+            if (find(langs.begin(), langs.end(), *it) == langs.end())
+                m_db.deleteStemDb(*it);
+        }
+        ret = ret && m_db.createStemDbs(langs);
         if (!ret) {
             addIdxReason("stemming", "stem db creation failed");
         }
@@ -379,7 +373,7 @@ bool ConfIndexer::createStemmingDatabases()
 bool ConfIndexer::createStemDb(const string &lang)
 {
     if (!m_db.open(Rcl::Db::DbUpd))
-    return false;
+        return false;
     vector<string> langs;
     stringToStrings(lang, langs);
     return m_db.createStemDbs(langs);
@@ -397,32 +391,32 @@ bool ConfIndexer::createAspellDict()
     // it forever.
     static int noaspell = -12345;
     if (noaspell == -12345) {
-    noaspell = false;
-    m_config->getConfParam("noaspell", &noaspell);
+        noaspell = false;
+        m_config->getConfParam("noaspell", &noaspell);
     }
     if (noaspell)
-    return true;
+        return true;
 
     if (!m_db.open(Rcl::Db::DbRO)) {
         LOGERR("ConfIndexer::createAspellDict: could not open db\n");
-    return false;
+        return false;
     }
 
     Aspell aspell(m_config);
     string reason;
     if (!aspell.init(reason)) {
-    LOGERR("ConfIndexer::createAspellDict: aspell init failed: " <<
+        LOGERR("ConfIndexer::createAspellDict: aspell init failed: " <<
                reason << "\n");
-    noaspell = true;
-    return false;
+        noaspell = true;
+        return false;
     }
     LOGDEB("ConfIndexer::createAspellDict: creating dictionary\n");
     if (!aspell.buildDict(m_db, reason)) {
-    LOGERR("ConfIndexer::createAspellDict: aspell buildDict failed: " <<
+        LOGERR("ConfIndexer::createAspellDict: aspell buildDict failed: " <<
                reason << "\n");
         addIdxReason("aspell", reason);
-    noaspell = true;
-    return false;
+        noaspell = true;
+        return false;
     }
 #endif
     return true;
@@ -432,4 +426,3 @@ vector<string> ConfIndexer::getStemmerNames()
 {
     return Rcl::Db::getStemmerNames();
 }
-
