@@ -28,6 +28,7 @@
 #endif
 #include "safefcntl.h"
 #include "safeunistd.h"
+#include <getopt.h>
 
 #include <iostream>
 #include <list>
@@ -46,6 +47,7 @@ using namespace std;
 #include "rclmon.h"
 #include "x11mon.h"
 #include "cancelcheck.h"
+#include "checkindexed.h"
 #include "rcldb.h"
 #include "readfile.h"
 #ifndef DISABLE_WEB_INDEXER
@@ -59,33 +61,48 @@ using namespace std;
 #include "execmd.h"
 #include "checkretryfailed.h"
 #include "idxstatus.h"
+#include "circache.h"
+#include "idxdiags.h"
 
 // Command line options
 static int     op_flags;
-#define OPT_MOINS 0x1
 #define OPT_C 0x1     
-#define OPT_D 0x2     
-#define OPT_E 0x4     
-#define OPT_K 0x8     
-#define OPT_P 0x10    
-#define OPT_R 0x20    
-#define OPT_S 0x40    
-#define OPT_Z 0x80    
-#define OPT_c 0x200   
-#define OPT_e 0x400   
-#define OPT_f 0x800   
-#define OPT_h 0x1000  
-#define OPT_i 0x2000  
-#define OPT_k 0x4000  
-#define OPT_l 0x8000  
-#define OPT_m 0x10000 
-#define OPT_n 0x20000
-#define OPT_p 0x40000
-#define OPT_r 0x80000 
+#define OPT_c 0x2
+#define OPT_d 0x4     
+#define OPT_D 0x8     
+#define OPT_E 0x10    
+#define OPT_e 0x20    
+#define OPT_f 0x40    
+#define OPT_h 0x80    
+#define OPT_i 0x200   
+#define OPT_K 0x400   
+#define OPT_k 0x800   
+#define OPT_l 0x1000  
+#define OPT_m 0x2000  
+#define OPT_n 0x4000  
+#define OPT_P 0x8000  
+#define OPT_p 0x10000 
+#define OPT_R 0x20000 
+#define OPT_r 0x40000 
+#define OPT_S 0x80000 
 #define OPT_s 0x100000
 #define OPT_w 0x200000
 #define OPT_x 0x400000
-#define OPT_z 0x800000
+#define OPT_Z 0x800000
+#define OPT_z 0x1000000
+
+#define OPTVAL_WEBCACHE_COMPACT 1000
+#define OPTVAL_WEBCACHE_BURST 1001
+#define OPTVAL_DIAGS_NOTINDEXED 1002
+#define OPTVAL_DIAGS_DIAGSFILE 1003
+
+static struct option long_options[] = {
+    {"webcache-compact", 0, 0, OPTVAL_WEBCACHE_COMPACT},
+    {"webcache-burst", required_argument, 0, OPTVAL_WEBCACHE_BURST},
+    {"notindexed", 0, 0, OPTVAL_DIAGS_NOTINDEXED},
+    {"diagsfile", required_argument, 0, OPTVAL_DIAGS_DIAGSFILE},
+    {0, 0, 0, 0}
+};
 
 ReExec *o_reexec;
 
@@ -96,6 +113,7 @@ static ConfIndexer *confindexer;
 static void cleanup()
 {
     deleteZ(confindexer);
+    IdxDiags::theDiags().flush();
     recoll_exitready();
 }
 
@@ -260,20 +278,15 @@ static void setMyPriority(const RclConfig *config)
 class MakeListWalkerCB : public FsTreeWalkerCB {
 public:
     MakeListWalkerCB(list<string>& files, const vector<string>& selpats)
-        : m_files(files), m_pats(selpats)
-        {
-        }
-    virtual FsTreeWalker::Status 
-    processone(const string& fn, const struct PathStat *,
-               FsTreeWalker::CbFlag flg) {
+        : m_files(files), m_pats(selpats) {}
+    virtual FsTreeWalker::Status processone(
+        const string& fn, const struct PathStat *, FsTreeWalker::CbFlag flg) {
         if (flg== FsTreeWalker::FtwDirEnter || flg == FsTreeWalker::FtwRegular){
             if (m_pats.empty()) {
-                cerr << "Selecting " << fn << endl;
                 m_files.push_back(fn);
             } else {
-                for (vector<string>::const_iterator it = m_pats.begin();
-                     it != m_pats.end(); it++) {
-                    if (fnmatch(it->c_str(), fn.c_str(), 0) == 0) {
+                for (const auto& pat : m_pats) {
+                    if (fnmatch(pat.c_str(), fn.c_str(), 0) == 0) {
                         m_files.push_back(fn);
                         break;
                     }
@@ -288,7 +301,7 @@ public:
 
 // Build a list of things to index, then call purgefiles and/or
 // indexfiles.  This is basically the same as find xxx | recollindex
-// -i [-e] without the find (so, simpler but less powerfull)
+// -i [-e] without the find (so, simpler but less powerful)
 bool recursive_index(RclConfig *config, const string& top, 
                      const vector<string>& selpats)
 {
@@ -363,7 +376,7 @@ static bool createstemdb(RclConfig *config, const string &lang)
     return confindexer->createStemDb(lang);
 }
 
-// Check that topdir entries are valid (successfull tilde exp + abs
+// Check that topdir entries are valid (successful tilde exp + abs
 // path) or fail.
 // In addition, topdirs, skippedPaths, daemSkippedPaths entries should
 // match existing files or directories. Warn if they don't
@@ -437,6 +450,8 @@ static const char usage [] =
 "    -Z : in place reset: consider all documents as changed. Can also\n"
 "         be combined with -i or -r but not -m\n"
 "    -k : retry files on which we previously failed\n"
+"    --diagsfile <outputpath> : list skipped or otherwise not indexed documents to <outputpath>\n"
+"       <outputpath> will be truncated\n"
 #ifdef RCL_MONITOR
 "recollindex -m [-w <secs>] -x [-D] [-C]\n"
 "    Perform real time indexing. Don't become a daemon if -D is set.\n"
@@ -465,6 +480,10 @@ static const char usage [] =
 "    Build stem database for additional language <lang>\n"
 "recollindex -E\n"
 "    Check configuration file for topdirs and other paths existence\n"
+"recollindex --webcache-compact : recover wasted space from the Web cache\n"
+"recollindex --webcache-burst <targetdir> : extract entries from the Web cache to the target\n"
+"recollindex --notindexed [filepath [filepath ...]] : check if the file arguments are indexed\n"
+"   will read file paths from stdin if there are no arguments\n"
 #ifdef FUTURE_IMPROVEMENT
 "recollindex -W\n"
 "    Process the Web queue\n"
@@ -475,7 +494,11 @@ static const char usage [] =
 #endif
 "Common options:\n"
 "    -c <configdir> : specify config directory, overriding $RECOLL_CONFDIR\n"
-                                                           ;
+#if defined(HAVE_POSIX_FADVISE)
+"    -d : call fadvise() with the POSIX_FADV_DONTNEED flag on indexed files\n"
+"          (avoids trashing the page cache)\n";
+#endif
+;
 
 static void Usage()
 {
@@ -543,8 +566,8 @@ static void flushIdxReasons()
             out.open(reasonsfile, ofstream::out|ofstream::trunc);
             idxreasons.write(out);
         } catch (...) {
-            cerr << "Could not write reasons file " << reasonsfile << endl;
-            idxreasons.write(cerr);
+            std::cerr << "Could not write reasons file " << reasonsfile << endl;
+            idxreasons.write(std::cerr);
         }
     }
 }
@@ -553,38 +576,28 @@ static void flushIdxReasons()
 // enable wmain.  Another workaround is to use main, then call
 // GetCommandLineW and CommandLineToArgvW, to then call wmain(). If
 // ever we need to build with mingw again.
-#define USE_WMAIN (defined(_WIN32) && defined(_MSC_VER))
+#if defined(_WIN32) && defined(_MSC_VER)
+#define USE_WMAIN 1
+#endif
 
 #if USE_WMAIN
 #define WARGTOSTRING(w) wchartoutf8(w)
-static vector<string> argstovector(int argc, wchar_t **argv)
+static vector<const char*> argstovector(int argc, wchar_t **argv, vector<string>& storage)
 #else
 #define WARGTOSTRING(w) (w)
-    static vector<string> argstovector(int argc, char **argv)
+    static vector<const char*> argstovector(int argc, char **argv, vector<string>& storage)
 #endif
 {
+    vector<const char *> args(argc+1);
+    storage.resize(argc+1);
     thisprog = path_absolute(WARGTOSTRING(argv[0]));
-    argc--; argv++;
-    vector<string> args;
     for (int i = 0; i < argc; i++) {
-        args.push_back(WARGTOSTRING(argv[i]));
+        storage[i] = WARGTOSTRING(argv[i]);
+        args[i] = storage[i].c_str();
     }
     return args;
 }
 
-static vector<string> fileToArgs(const string& fn)
-{
-    string reason, data;
-    if (!file_to_string(fn, data, &reason)) {
-        std::cerr << "Failed reading args file " << fn << " reason " <<
-            reason << "\n";
-        exit(1);
-    }
-    vector<string> args;
-    stringToStrings(data, args);
-    return args;
-}
-
 
 // Working directory before we change: it's simpler to change early
 // but some options need the original for computing absolute paths.
@@ -595,8 +608,8 @@ static std::string orig_cwd;
 // Unicode. It was first thought possible to use a temporary file to
 // hold the args, and make sure that the path for this would be ASCII,
 // based on using shortpath(). Unfortunately, this does not work in
-// all cases, so the second change was to use wmain(), but the
-// now largely redundant args-in-file passing trick was kept anyway.
+// all cases, so the second change was to use wmain(). The
+// args-in-file was removed quite a long time after.
 #if USE_WMAIN
 int wmain(int argc, wchar_t *argv[])
 #else
@@ -611,75 +624,72 @@ int main(int argc, char *argv[])
     o_reexec->init(argc, argv);
 #endif
 
-    vector<string> args = argstovector(argc, argv);
-
-    // Passing args through a temp file: this is used on Windows to
-    // avoid issues with charsets in args (thought to avoid using
-    // wmain, which proved false, but the args file was kept)
-    if (args.size() == 1 && args[0][0] != '-') {
-        args = fileToArgs(args[0]);
-    }
+    // Only actually useful on Windows: convert wargs to utf-8 chars
+    vector<string> astore;
+    vector<const char*> args = argstovector(argc, argv, astore);
 
     vector<string> selpatterns;
     int sleepsecs{60};
     string a_config;
-    unsigned int aremain = args.size();
-    unsigned int argidx = 0;
-    for (; argidx < args.size(); argidx++) {
-        const string& arg{args[argidx]};
-        aremain = args.size() - argidx;
-        if (arg[0] != '-') {
-            break;
-        }
-        for (unsigned int cidx = 1; cidx < arg.size(); cidx++) {
-            switch (arg[cidx]) {
-            case 'c':   op_flags |= OPT_c; if (aremain < 2)  Usage();
-                a_config = args[argidx+1]; argidx++; goto b1;
+    int ret;
+    bool webcache_compact{false};
+    bool webcache_burst{false};
+    bool diags_notindexed{false};
+    
+    std::string burstdir;
+    std::string diagsfile;
+    while ((ret = getopt_long(argc, (char *const*)&args[0], "c:CDdEefhikKlmnPp:rR:sS:w:xZz",
+                              long_options, NULL)) != -1) {
+        switch (ret) {
+        case 'c':  op_flags |= OPT_c; a_config = optarg; break;
 #ifdef RCL_MONITOR
-            case 'C': op_flags |= OPT_C; break;
-            case 'D': op_flags |= OPT_D; break;
+        case 'C': op_flags |= OPT_C; break;
+        case 'D': op_flags |= OPT_D; break;
 #endif
-            case 'E': op_flags |= OPT_E; break;
-            case 'e': op_flags |= OPT_e; break;
-            case 'f': op_flags |= OPT_f; break;
-            case 'h': op_flags |= OPT_h; break;
-            case 'i': op_flags |= OPT_i; break;
-            case 'k': op_flags |= OPT_k; break;
-            case 'K': op_flags |= OPT_K; break;
-            case 'l': op_flags |= OPT_l; break;
-            case 'm': op_flags |= OPT_m; break;
-            case 'n': op_flags |= OPT_n; break;
-            case 'P': op_flags |= OPT_P; break;
-            case 'p': op_flags |= OPT_p; if (aremain < 2)  Usage();
-                selpatterns.push_back(args[argidx+1]); argidx++; goto b1;
-            case 'r': op_flags |= OPT_r; break;
-            case 'R':   op_flags |= OPT_R; if (aremain < 2)  Usage();
-                reasonsfile = args[argidx+1]; argidx++; goto b1;
-            case 's': op_flags |= OPT_s; break;
+#if defined(HAVE_POSIX_FADVISE)
+        case 'd': op_flags |= OPT_d; break;
+#endif
+        case 'E': op_flags |= OPT_E; break;
+        case 'e': op_flags |= OPT_e; break;
+        case 'f': op_flags |= OPT_f; break;
+        case 'h': op_flags |= OPT_h; break;
+        case 'i': op_flags |= OPT_i; break;
+        case 'k': op_flags |= OPT_k; break;
+        case 'K': op_flags |= OPT_K; break;
+        case 'l': op_flags |= OPT_l; break;
+        case 'm': op_flags |= OPT_m; break;
+        case 'n': op_flags |= OPT_n; break;
+        case 'P': op_flags |= OPT_P; break;
+        case 'p': op_flags |= OPT_p; selpatterns.push_back(optarg); break;
+        case 'r': op_flags |= OPT_r; break;
+        case 'R':   op_flags |= OPT_R; reasonsfile = optarg; break;
+        case 's': op_flags |= OPT_s; break;
 #ifdef RCL_USE_ASPELL
-            case 'S': op_flags |= OPT_S; break;
+        case 'S': op_flags |= OPT_S; break;
 #endif
-            case 'w':   op_flags |= OPT_w; if (aremain < 2)  Usage();
-                if ((sscanf(args[argidx+1].c_str(), "%d", &sleepsecs)) != 1) 
-                    Usage(); 
-                argidx++; goto b1;
-            case 'x': op_flags |= OPT_x; break;
-            case 'Z': op_flags |= OPT_Z; break;
-            case 'z': op_flags |= OPT_z; break;
-            default: Usage(); break;
-            }
+        case 'w':   op_flags |= OPT_w;
+            if ((sscanf(optarg, "%d", &sleepsecs)) != 1) 
+                Usage(); 
+            break;
+        case 'x': op_flags |= OPT_x; break;
+        case 'Z': op_flags |= OPT_Z; break;
+        case 'z': op_flags |= OPT_z; break;
+
+        case OPTVAL_WEBCACHE_COMPACT: webcache_compact = true; break;
+        case OPTVAL_WEBCACHE_BURST: burstdir = optarg; webcache_burst = true;break;
+        case OPTVAL_DIAGS_NOTINDEXED: diags_notindexed = true;break;
+        case OPTVAL_DIAGS_DIAGSFILE: diagsfile = optarg;break;
+        default: Usage(); break;
         }
-    b1:
-        ;
     }
-    aremain = args.size() - argidx;
+    int aremain = argc - optind;
 
     if (op_flags & OPT_h)
         Usage();
 
 #ifndef RCL_MONITOR
     if (op_flags & (OPT_m | OPT_w|OPT_x)) {
-        cerr << "-m not available: real-time monitoring was not "
+        std::cerr << "-m not available: real-time monitoring was not "
             "configured in this build\n";
         exit(1);
     }
@@ -702,9 +712,37 @@ int main(int argc, char *argv[])
     if (config == 0 || !config->ok()) {
         addIdxReason("init", reason);
         flushIdxReasons();
-        cerr << "Configuration problem: " << reason << endl;
+        std::cerr << "Configuration problem: " << reason << endl;
         exit(1);
     }
+
+    // Auxiliary, non-index-related things. Avoids having a separate binary.
+    if (webcache_compact || webcache_burst || diags_notindexed) {
+        std::string ccdir = config->getWebcacheDir();
+        std::string reason;
+        if (webcache_compact) {
+            if (!CirCache::compact(ccdir, &reason)) {
+                std::cerr << "Web cache compact failed: " << reason << "\n";
+                exit(1);
+            }
+        } else if (webcache_burst) {
+            if (!CirCache::burst(ccdir, burstdir, &reason)) {
+                std::cerr << "Web cache burst failed: " << reason << "\n";
+                exit(1);
+            }
+        } else if (diags_notindexed) {
+            std::vector<std::string> filepaths;
+            while (aremain--) {
+                filepaths.push_back(args[optind++]);
+            }
+            if (!checkindexed(config, filepaths)) {
+                exit(1);
+            }
+        }
+            
+        exit(0);
+    }
+
 #ifndef _WIN32
     o_reexec->atexit(cleanup);
 #endif
@@ -754,6 +792,12 @@ int main(int argc, char *argv[])
         }
     }
 
+    if (!diagsfile.empty()) {
+        if (!IdxDiags::theDiags().init(diagsfile)) {
+            std::cerr << "Could not initialize diags file " << diagsfile << "\n";
+            LOGERR("recollindex: Could not initialize diags file " << diagsfile << "\n");
+        }
+    }
     bool rezero((op_flags & OPT_z) != 0);
     bool inPlaceReset((op_flags & OPT_Z) != 0);
 
@@ -780,6 +824,12 @@ int main(int argc, char *argv[])
         LOGDEB("recollindex: files in error will be retried\n");
     }
 
+#if defined(HAVE_POSIX_FADVISE)
+    if (op_flags & OPT_d) {
+        indexerFlags |= ConfIndexer::IxFCleanCache;
+    }
+#endif
+    
     Pidfile pidfile(config->getPidfile());
     updater = new MyUpdater(config);
     lockorexit(&pidfile, config);
@@ -792,7 +842,7 @@ int main(int argc, char *argv[])
     if (op_flags & OPT_r) {
         if (aremain != 1) 
             Usage();
-        string top = args[argidx++]; aremain--;
+        string top = args[optind++]; aremain--;
         top = path_canon(top, &orig_cwd);
         bool status = recursive_index(config, top, selpatterns);
         if (confindexer && !confindexer->getReason().empty()) {
@@ -813,7 +863,7 @@ int main(int argc, char *argv[])
             }
         } else {
             while (aremain--) {
-                filenames.push_back(args[argidx++]);
+                filenames.push_back(args[optind++]);
             }
         }
 
@@ -836,7 +886,7 @@ int main(int argc, char *argv[])
     } else if (op_flags & OPT_s) {
         if (aremain != 1) 
             Usage();
-        string lang = args[argidx++]; aremain--;
+        string lang = args[optind++]; aremain--;
         exit(!createstemdb(config, lang));
 
 #ifdef RCL_USE_ASPELL
