@@ -65,13 +65,19 @@ public:
     bool getFromCache(const std::string& udi, Rcl::Doc &doc, std::string& data,
                       std::string *hittype = 0);
 private:
-    RclConfig *m_config;
-    Rcl::Db   *m_db;
-    WebStore  *m_cache;
+    RclConfig *m_config{nullptr};
+    Rcl::Db   *m_db{nullptr};
+    WebStore  *m_cache{nullptr};
     std::string     m_queuedir;
-    DbIxStatusUpdater *m_updater;
-    bool       m_nocacheindex;
-
+    DbIxStatusUpdater *m_updater{nullptr};
+    // Don't process the cache. Set by indexFiles().
+    bool       m_nocacheindex{false};
+    // Config: page erase interval. We normally keep only one
+    // instance. This can be set to "day", "week", "month", "year" to
+    // keep more.
+    enum KeepInterval {WQKI_NONE, WQKI_DAY, WQKI_WEEK, WQKI_MONTH, WQKI_YEAR};
+    KeepInterval  m_keepinterval{WQKI_NONE};
+    
     bool indexFromCache(const std::string& udi);
     void updstatus(const std::string& udi);
 };
