@@ -34,7 +34,6 @@
 #include <string>
 #include <map>
 #include <algorithm>
-using namespace std;
 
 #include "recoll.h"
 #include "rclconfig.h"
@@ -42,6 +41,9 @@ using namespace std;
 #include "searchdata.h"
 #include "guiutils.h"
 #include "rclhelp.h"
+#include "scbase.h"
+
+using namespace std;
 
 static const int initclausetypes[] = {1, 3, 0, 2, 5};
 static const unsigned int iclausescnt = sizeof(initclausetypes) / sizeof(int);
@@ -78,8 +80,9 @@ void AdvSearch::init()
     connect(addClausePB, SIGNAL(clicked()), this, SLOT(addClause()));
     connect(delClausePB, SIGNAL(clicked()), this, SLOT(delClause()));
 
-    new QShortcut(QKeySequence(Qt::Key_Up), this, SLOT(slotHistoryNext()));;
-    new QShortcut(QKeySequence(Qt::Key_Down), this, SLOT(slotHistoryPrev()));
+    onNewShortcuts();
+    connect(&SCBase::scBase(), SIGNAL(shortcutsChanged()),
+            this, SLOT(onNewShortcuts()));
 
     conjunctCMB->insertItem(1, tr("All clauses"));
     conjunctCMB->insertItem(2, tr("Any clause"));
@@ -163,6 +166,26 @@ void AdvSearch::saveCnf()
     }
 }
 
+void AdvSearch::onNewShortcuts()
+{
+    SETSHORTCUT(this, "advsearch:171",
+                tr("Advanced Search"), tr("Load next stored search"),
+                "Up", m_histnextsc, slotHistoryNext);
+    SETSHORTCUT(this, "advsearch:174",
+                tr("Advanced Search"), tr("Load previous stored search"),
+                "Down", m_histprevsc, slotHistoryPrev);
+}
+
+void AdvSearch::listShortcuts()
+{
+    LISTSHORTCUT(this,  "advsearch:171",
+                 tr("Advanced Search"), tr("Load next stored search"),
+                "Up", m_histnextsc, slotHistoryNext);
+    LISTSHORTCUT(this, "advsearch:174",
+                 tr("Advanced Search"), tr("Load previous stored search"),
+                "Down", m_histprevsc, slotHistoryPrev);
+}
+
 void AdvSearch::addClause(bool updsaved)
 {
     addClause(0, updsaved);
