@@ -89,7 +89,6 @@ public:
         return m_indexerState;
     }
     void enableTrayIcon(bool onoff);
-    QString readDarkCSS();
     void setupToolbars();
     void setupStatusBar();
     void buildMenus();
@@ -120,7 +119,6 @@ public slots:
     virtual void showDocHistory();
     virtual void showExtIdxDialog();
     virtual void setSynEnabled(bool);
-    virtual void setDarkModeEnabled(bool);
     virtual void showUIPrefs();
     virtual void showIndexConfig();
     virtual void execIndexConfig();
@@ -167,7 +165,12 @@ public slots:
     virtual void setFilterCtlStyle(int stl);
     virtual void showTrayMessage(const QString& text);
     virtual void onSetDescription(QString);
-                                          
+    virtual void onNewShortcuts();
+    virtual void toggleTable();
+    virtual void hideToolTip();
+    virtual void zoomIn();
+    virtual void zoomOut();
+
 private slots:
     virtual void updateIdxStatus();
     virtual void onWebcacheDestroyed(QObject *);
@@ -215,13 +218,16 @@ private:
     QComboBox      *m_filtCMB{0};
     QButtonGroup   *m_filtBGRP{0};
     QMenu          *m_filtMN{0};
-    QShortcut      *m_tablefocseq{0};
+    QShortcut      *m_focustotablesc{0};
+    QShortcut      *m_focustosearchsc{0};
+    QShortcut      *m_focustosearcholdsc{0};
+    QShortcut      *m_clearsearchsc{0};
+    QShortcut      *m_toggletablesc{0};
     QFileSystemWatcher m_watcher;
     vector<ExecCmd*>  m_viewers;
     ExecCmd          *m_idxproc{0}; // Indexing process
     bool             m_idxkilled{false}; // Killed my process
     TempFile        *m_idxreasontmp{nullptr};
-    TempFile        *m_idxargstmp{nullptr};
     map<QString, QAction*> m_stemLangToId;
     vector<string>    m_catgbutvec;
     int               m_catgbutvecidx{0};
@@ -277,7 +283,6 @@ private:
     virtual bool containerUpToDate(Rcl::Doc& doc);
     virtual void setFiltSpec();
     virtual bool checkIdxPaths();
-    bool maybeArgsToFile(std::vector<std::string>& args);
 };
 
 #endif // RCLMAIN_W_H
