@@ -133,18 +133,18 @@ public:
     QtGuiResListPager(ResList *p, int ps, bool alwayssnip) 
         : ResListPager(ps, alwayssnip), m_reslist(p) 
         {}
-    virtual bool append(const string& data);
-    virtual bool append(const string& data, int idx, const Rcl::Doc& doc);
-    virtual string trans(const string& in);
-    virtual string detailsLink();
-    virtual const string &parFormat();
-    virtual const string &dateFormat();
-    virtual string nextUrl();
-    virtual string prevUrl();
-    virtual string headerContent();
+    virtual bool append(const string& data) override;
+    virtual bool append(const string& data, int idx, const Rcl::Doc& doc) override;
+    virtual string trans(const string& in) override;
+    virtual string detailsLink() override;
+    virtual const string &parFormat() override;
+    virtual const string &dateFormat() override;
+    virtual string nextUrl() override;
+    virtual string prevUrl() override;
+    virtual string headerContent() override;
     virtual void suggest(const vector<string>uterms, 
-                         map<string, vector<string> >& sugg);
-    virtual string absSep() {return (const char *)(prefs.abssep.toUtf8());}
+                         map<string, vector<string> >& sugg) override;
+    virtual string absSep() override {return (const char *)(prefs.abssep.toUtf8());}
 
 #if defined(USING_WEBENGINE) || defined(USING_WEBKIT)
     // We used to use http://localhost/. Now use file:/// as this is
@@ -218,7 +218,7 @@ const string& QtGuiResListPager::parFormat()
 }
 const string& QtGuiResListPager::dateFormat()
 {
-    return prefs.creslistdateformat;
+    return prefs.reslistdateformat;
 }
 
 string QtGuiResListPager::nextUrl()
@@ -250,6 +250,7 @@ string QtGuiResListPager::headerContent()
     out += locdetailscript;
     out += "</script>\n";
 #endif
+    out += qs2utf8s(prefs.darkreslistheadertext);
     out += qs2utf8s(prefs.reslistheadertext);
     return out;
 }
@@ -437,25 +438,25 @@ void ResList::onUiPrefsChanged()
 void ResList::setFont()
 {
 #if defined(USING_WEBKIT) || defined(USING_WEBENGINE)
-#  ifndef SETFONT_WITH_HEADSTYLE
-    if (prefs.reslistfontfamily.length()) {
+#ifndef SETFONT_WITH_HEADSTYLE
+    if (prefs.reslistfontfamily != "") {
         // For some reason there is (12-2014) an offset of 3 between what
         // we request from webkit and what we get.
-        settings()->setFontSize(QWEBSETTINGS::DefaultFontSize, 
-                                prefs.reslistfontsize + 3);
-        settings()->setFontFamily(QWEBSETTINGS::StandardFont, 
-                                  prefs.reslistfontfamily);
+        settings()->setFontSize(QWEBSETTINGS::DefaultFontSize, prefs.reslistfontsize + 3);
+        settings()->setFontFamily(QWEBSETTINGS::StandardFont,  prefs.reslistfontfamily);
     } else {
-        settings()->resetFontSize(QWEBSETTINGS::DefaultFontSize);
+        settings()->setFontSize(QWEBSETTINGS::DefaultFontSize, prefs.reslistfontsize + 3);
         settings()->resetFontFamily(QWEBSETTINGS::StandardFont);
     }
-# endif
+#endif
 #else
-    if (prefs.reslistfontfamily.length()) {
+    if (prefs.reslistfontfamily != "") {
         QFont nfont(prefs.reslistfontfamily, prefs.reslistfontsize);
         QTextBrowser::setFont(nfont);
     } else {
-        QTextBrowser::setFont(QFont());
+        QFont font;
+        font.setPointSize(prefs.reslistfontsize);
+        QTextBrowser::setFont(font);
     }
 #endif
 }
@@ -1267,6 +1268,20 @@ void ResList::menuCopyFN()
         ResultPopup::copyFN(doc);
 }
 
+void ResList::menuCopyPath()
+{
+    Rcl::Doc doc;
+    if (getDoc(m_popDoc, doc))
+        ResultPopup::copyPath(doc);
+}
+
+void ResList::menuCopyText()
+{
+    Rcl::Doc doc;
+    if (getDoc(m_popDoc, doc))
+        ResultPopup::copyText(doc, m_rclmain);
+}
+
 void ResList::menuCopyURL()
 {
     Rcl::Doc doc;
