@@ -40,6 +40,8 @@
 #include <QMessageBox>
 #include <QTimer>
 #include <QKeyEvent>
+#include <QClipboard>
+#include <QToolTip>
 
 #include "recoll.h"
 #include "docseq.h"
@@ -55,6 +57,7 @@
 #include "multisave.h"
 #include "appformime.h"
 #include "transcode.h"
+#include "scbase.h"
 
 static const QKeySequence quitKeySeq("Ctrl+q");
 static const QKeySequence closeKeySeq("Ctrl+w");
@@ -90,7 +93,8 @@ public:
     virtual string absSep() override {
         return (const char *)(prefs.abssep.toUtf8());}
     virtual string headerContent() override {
-        return qs2utf8s(prefs.reslistheadertext);}
+        return qs2utf8s(prefs.darkreslistheadertext) + qs2utf8s(prefs.reslistheadertext);
+    }
 private:
     ResTable *m_parent;
     string m_data;
@@ -101,8 +105,16 @@ bool ResTablePager::append(const string& data)
     m_data += data;
     return true;
 }
+
 bool ResTablePager::flush()
 {
+#ifdef helps_discoverability_of_shiftclick_but_is_ennoying
+    QString msg = QApplication::translate(
+        "ResTable", "Use Shift+click to display the text instead.");
+    if (!prefs.resTableTextNoShift) {
+        m_data += std::string("<p>") + qs2utf8s(msg) + "</p>";
+    }
+#endif
     m_parent->m_detail->setHtml(u8s2qs(m_data));
     m_data = "";
     return true;
@@ -144,16 +156,18 @@ void ResTableDetailArea::createPopupMenu(const QPoint& pos)
 
 void ResTableDetailArea::setFont()
 {
-    if (prefs.reslistfontsize) {
-        // fs shows slightly bigger in qtextbrowser? adjust.
-        int fs = prefs.reslistfontsize;
-        if (prefs.reslistfontsize > fsadjustdetail) {
-            fs -= fsadjustdetail;
-        }
+    int fs = prefs.reslistfontsize;
+    // fs shows slightly bigger in qtextbrowser? adjust.
+    if (prefs.reslistfontsize > fsadjustdetail) {
+        fs -= fsadjustdetail;
+    }
+    if (prefs.reslistfontfamily != "") {
         QFont nfont(prefs.reslistfontfamily, fs);
         QTextBrowser::setFont(nfont);
     } else {
-        QTextBrowser::setFont(QFont());
+        QFont font;
+        font.setPointSize(fs);
+        QTextBrowser::setFont(font);
     }
 }
 
@@ -208,7 +222,8 @@ static string datetimegetter(const string&, const Rcl::Doc& doc)
         time_t mtime = doc.dmtime.empty() ?
             atoll(doc.fmtime.c_str()) : atoll(doc.dmtime.c_str());
         struct tm *tm = localtime(&mtime);
-        datebuf = utf8datestring(prefs.creslistdateformat.c_str(), tm);
+        // Can't use reslistdateformat because it's html (&nbsp; etc.)
+        datebuf = utf8datestring("%Y-%m-%d %H:%M:%S", tm);
     }
     return datebuf;
 }
@@ -359,7 +374,11 @@ QVariant RecollModel::headerData(int idx, Qt::Orientation orientation,
             (orientation == Qt::Vertical ? "vertical":"horizontal") <<
             " role " << role << "\n");
     if (orientation == Qt::Vertical && role == Qt::DisplayRole) {
-        return idx;
+        if (idx < 26) {
+            return QString("%1/%2").arg(idx).arg(char('a'+idx)); 
+        } else {
+            return idx;
+        }
     }
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole &&
         idx < int(m_fields.size())) {
@@ -567,6 +586,7 @@ void ResTable::setDefRowHeight()
             font.setPointSize(fs);
         QFontMetrics fm(font);
         header->setDefaultSectionSize(fm.height() + ROWHEIGHTPAD);
+        header->setSectionResizeMode(QHeaderView::Fixed);
     }
 }
 
@@ -588,11 +608,16 @@ void ResTable::init()
     tableView->setSelectionBehavior(QAbstractItemView::SelectRows);
     tableView->setItemDelegate(new ResTableDelegate(this));
     tableView->setContextMenuPolicy(Qt::CustomContextMenu);
-    new QShortcut(QKeySequence("Ctrl+o"), this, SLOT(menuEdit()));
-    new QShortcut(QKeySequence("Ctrl+Shift+o"), this, SLOT(menuEditAndQuit()));
-    new QShortcut(QKeySequence("Ctrl+d"), this, SLOT(menuPreview()));
-    new QShortcut(QKeySequence("Ctrl+e"), this, SLOT(menuShowSnippets()));
+    tableView->setAlternatingRowColors(true);
+    
+    onNewShortcuts();
+    connect(&SCBase::scBase(), SIGNAL(shortcutsChanged()),
+            this, SLOT(onNewShortcuts()));
 
+    auto sc = new QShortcut(QKeySequence(Qt::Key_Escape), this);
+    connect(sc, SIGNAL(activated()),
+            tableView->selectionModel(), SLOT(clear()));
+    
     connect(tableView, SIGNAL(customContextMenuRequested(const QPoint&)),
             this, SLOT(createPopupMenu(const QPoint&)));
 
@@ -624,16 +649,15 @@ void ResTable::init()
 #else
     header->setMovable(true);
 #endif
-
     setDefRowHeight();
 
-    QShortcut *sc = new QShortcut(QKeySequence(Qt::Key_Escape), this);
-    connect(sc, SIGNAL(activated()), tableView->selectionModel(), SLOT(clear()));
     connect(tableView->selectionModel(), 
             SIGNAL(currentChanged(const QModelIndex&, const QModelIndex &)),
             this, SLOT(onTableView_currentChanged(const QModelIndex&)));
     connect(tableView, SIGNAL(doubleClicked(const QModelIndex&)), 
             this, SLOT(onDoubleClick(const QModelIndex&)));
+    connect(tableView, SIGNAL(clicked(const QModelIndex&)), 
+            this, SLOT(onClicked(const QModelIndex&)));
 
     m_pager = new ResTablePager(this);
     m_pager->setHighLighter(&g_hiliter);
@@ -658,20 +682,73 @@ void ResTable::init()
         splitter->setSizes(sizes);
     }
     installEventFilter(this);
+    onUiPrefsChanged();
 }
 
-bool ResTable::eventFilter(QObject* obj, QEvent* event)
+void ResTable::onNewShortcuts()
+{
+    if (prefs.noResTableRowJumpSC) {
+        for (auto& lnk : m_rowlinks) {
+            delete lnk;
+        }
+        m_rowlinks.clear();
+        for (auto& sc : m_rowsc) {
+            delete sc;
+        }
+        m_rowsc.clear();
+    } else if (m_rowlinks.empty()) {
+        // Set "go to row" accelerator shortcuts. letter or digit for 0-9,
+        // then letter up to 25
+        std::function<void(int)> setrow =
+            std::bind(&ResTable::setCurrentRowFromKbd, this, std::placeholders::_1);
+        for (int i = 0; i <= 25; i++) {
+            auto qs = QString("Ctrl+Shift+%1").arg(char('a'+i));
+            auto sc = new QShortcut(QKeySequence(qs2utf8s(qs).c_str()), this);
+            m_rowlinks.push_back(new SCData(this, setrow, i));
+            m_rowsc.push_back(sc);
+            connect(sc, SIGNAL(activated()), m_rowlinks.back(), SLOT(activate()));
+            if (i > 9)
+                continue;
+            qs = QString("Ctrl+%1").arg(i);
+            sc = new QShortcut(QKeySequence(qs2utf8s(qs).c_str()), this);
+            m_rowsc.push_back(sc);
+            m_rowlinks.push_back(new SCData(this, setrow, i));
+            connect(sc, SIGNAL(activated()), m_rowlinks.back(), SLOT(activate()));
+        }
+    }
+    SETSHORTCUT(this, "restable:704", tr("Result Table"),
+                tr("Open current result document"),"Ctrl+O", m_opensc, menuEdit);
+    SETSHORTCUT(this, "restable:706", tr("Result Table"),
+                tr("Open current result and quit"),
+                "Ctrl+Shift+O", m_openquitsc, menuEditAndQuit);
+    SETSHORTCUT(this, "restable:709", tr("Result Table"), tr("Preview"),
+                "Ctrl+D", m_previewsc, menuPreview);
+    SETSHORTCUT(this, "restable:711", tr("Result Table"), tr("Show snippets"),
+                "Ctrl+E", m_showsnipssc, menuShowSnippets);
+    SETSHORTCUT(this, "restable:713", tr("Result Table"), tr("Show header"),
+                "Ctrl+H", m_showheadersc, toggleHeader);
+    SETSHORTCUT(this, "restable:715", tr("Result Table"),
+                tr("Show vertical header"),
+                "Ctrl+V", m_showvheadersc, toggleVHeader);
+    SETSHORTCUT(this, "restable:718", tr("Result Table"),
+                tr("Copy current result text to clipboard"),
+                "Ctrl+G", m_copycurtextsc, menuCopyText);
+    std::vector<QShortcut*> scps={
+        m_opensc, m_openquitsc, m_previewsc, m_showsnipssc, m_showheadersc,
+        m_showvheadersc, m_copycurtextsc};
+    for (auto& scp : scps) {
+        scp->setContext(Qt::WidgetWithChildrenShortcut);
+    }
+}
+
+bool ResTable::eventFilter(QObject*, QEvent *event)
 {
     if (event->type() == QEvent::KeyPress) {
         QKeyEvent* key = static_cast<QKeyEvent*>(event);
         if ((key->key() == Qt::Key_Enter) || (key->key() == Qt::Key_Return)) {
             menuEdit();
             return true;
-        } else {
-            return QObject::eventFilter(obj, event);
         }
-    } else {
-        return QObject::eventFilter(obj, event);
     }
     return false;
 }
@@ -707,11 +784,59 @@ void ResTable::setRclMain(RclMain *m, bool ismain)
             m_rclmain, SLOT(showSnippets(Rcl::Doc)));
 }
 
+void ResTable::toggleHeader()
+{
+    if (tableView->horizontalHeader()->isVisible()) {
+        prefs.noResTableHeader = true;
+        tableView->horizontalHeader()->hide();
+    } else {
+        prefs.noResTableHeader = false;
+        tableView->horizontalHeader()->show();
+    }
+}
+
+void ResTable::toggleVHeader()
+{
+    if (tableView->verticalHeader()->isVisible()) {
+        prefs.showResTableVHeader = false;
+        tableView->verticalHeader()->hide();
+    } else {
+        prefs.showResTableVHeader = true;
+        tableView->verticalHeader()->show();
+    }
+}
+
 void ResTable::onUiPrefsChanged()
 {
     if (m_detail) {
-        m_detail->init();
+        m_detail->setFont();
     }        
+    auto index = tableView->indexAt(QPoint(0, 0));
+    // There may be a better way to force repainting all visible rows
+    // with the possibly new font, but this works...
+    tableView->setAlternatingRowColors(false);
+    tableView->setAlternatingRowColors(true);
+    makeRowVisible(index.row());
+    if (prefs.noResTableHeader) {
+        tableView->horizontalHeader()->hide();
+    } else {
+        tableView->horizontalHeader()->show();
+    }
+    if (prefs.showResTableVHeader) {
+        tableView->verticalHeader()->show();
+    } else {
+        tableView->verticalHeader()->hide();
+    }
+}
+
+void ResTable::setCurrentRowFromKbd(int row)
+{
+    LOGDEB1("setCurrentRowFromKbd: " << row << "\n");
+    m_rowchangefromkbd = true;
+    tableView->setFocus(Qt::ShortcutFocusReason);                     
+    tableView->selectionModel()->setCurrentIndex(                     
+        m_model->index(row, 0),                                       
+        QItemSelectionModel::ClearAndSelect|QItemSelectionModel::Rows);
 }
 
 int ResTable::getDetailDocNumOrTopRow()
@@ -766,8 +891,10 @@ void ResTable::saveColState()
 
 void ResTable::onTableView_currentChanged(const QModelIndex& index)
 {
+    bool hasselection = tableView->selectionModel()->hasSelection();
     LOGDEB2("ResTable::onTableView_currentChanged(" << index.row() << ", " <<
-            index.column() << ")\n");
+        index.column() << ") from kbd " << m_rowchangefromkbd  << " hasselection " <<
+            hasselection << "\n");
 
     if (!m_model || !m_model->getDocSource())
         return;
@@ -776,8 +903,31 @@ void ResTable::onTableView_currentChanged(const QModelIndex& index)
         m_detail->init();
         m_detaildocnum = index.row();
         m_detaildoc = doc;
-        m_pager->displaySingleDoc(theconfig, m_detaildocnum, m_detaildoc, 
-                                  m_model->m_hdata);
+        bool isShift = (QApplication::keyboardModifiers() & Qt::ShiftModifier);
+        bool showtext{false};
+        bool showmeta{false};
+        if (m_rowchangefromkbd) {
+            // Ctrl+... jump to row. Show text/meta as for simple click
+            if (hasselection) {
+                // When getting here from ctrl+... we get called twice, once with row 0
+                // and no selection, once with the actual row and selection. Only
+                // reset fromkbd and set showtext in the second case.
+                m_rowchangefromkbd = false;
+                showtext = prefs.resTableTextNoShift;
+            }
+        } else {
+            // Mouse click. Show text or meta depending on shift key. Never show text when hovering
+            // (no selection).
+            showtext = hasselection && (isShift ^ prefs.resTableTextNoShift);
+        }
+        if (!showtext) {
+            showmeta = hasselection || !prefs.resTableNoHoverMeta;
+        }
+        if (showtext && rcldb->getDocRawText(m_detaildoc)) {
+            m_detail->setPlainText(u8s2qs(m_detaildoc.text));
+        }  else if (showmeta) {
+            m_pager->displaySingleDoc(theconfig, m_detaildocnum, m_detaildoc, m_model->m_hdata);
+        }
         emit(detailDocChanged(doc, m_model->getDocSource()));
     } else {
         m_detaildocnum = -1;
@@ -967,8 +1117,20 @@ void ResTable::linkWasClicked(const QUrl &url)
     }
 }
 
+void ResTable::onClicked(const QModelIndex& index)
+{
+    // If the current row is the one clicked, currentChanged is not
+    // called so that we would not do the text display if we did not
+    // call it from here
+    m_rowchangefromkbd = false;
+    if (index.row() == m_detaildocnum) {
+        onTableView_currentChanged(index);
+    }
+}
+    
 void ResTable::onDoubleClick(const QModelIndex& index)
 {
+    m_rowchangefromkbd = false;
     if (!m_model || !m_model->getDocSource())
         return;
     Rcl::Doc doc;
@@ -1109,12 +1271,46 @@ void ResTable::menuCopyFN()
         ResultPopup::copyFN(m_detaildoc);
 }
 
+void ResTable::menuCopyPath()
+{
+    if (m_detaildocnum >= 0) 
+        ResultPopup::copyPath(m_detaildoc);
+}
+
 void ResTable::menuCopyURL()
 {
     if (m_detaildocnum >= 0) 
         ResultPopup::copyURL(m_detaildoc);
 }
 
+void ResTable::menuCopyText()
+{
+    if (m_detaildocnum >= 0 && rcldb) {
+        ResultPopup::copyText(m_detaildoc, m_rclmain);
+        if (m_rclmain) {
+            auto msg = tr("%1 bytes copied to clipboard").arg(m_detaildoc.text.size());
+            // Feedback was requested: tray messages are too ennoying, not
+            // everybody displays the status bar, and the tool tip only
+            // works when the copy is triggered through a shortcut (else,
+            // it appears that the mouse event cancels it and it's not
+            // shown). So let's do status bar if visible else tooltip.
+            //  Menu trigger with no status bar -> no feedback...
+        
+            // rclmain->showTrayMessage(msg);
+            if (m_rclmain->statusBar()->isVisible()) {
+                m_rclmain->statusBar()->showMessage(msg, 1000);
+            } else {
+                int x = tableView->columnViewportPosition(0) + tableView->width() / 2 ;
+                int y = tableView->rowViewportPosition(m_detaildocnum);
+                QPoint pos = tableView->mapToGlobal(QPoint(x,y));
+                QToolTip::showText(pos, msg);
+                QTimer::singleShot(1500, m_rclmain, SLOT(hideToolTip()));
+            }
+        }
+        
+    }
+}
+
 void ResTable::menuExpand()
 {
     if (m_detaildocnum >= 0) 
