@@ -43,6 +43,8 @@
 #include <QTimer>
 #include <QListWidget>
 #include <QSettings>
+#include <QKeySequenceEdit>
+#include <QKeySequence>
 
 #include "recoll.h"
 #include "guiutils.h"
@@ -54,11 +56,11 @@
 #include "editdialog.h"
 #include "rclmain_w.h"
 #include "ptrans_w.h"
+#include "scbase.h"
+#include "rclhelp.h"
 
 void UIPrefsDialog::init()
 {
-    m_viewAction = 0;
-
     // See enum above and keep in order !
     ssearchTypCMB->addItem(tr("Any term"));
     ssearchTypCMB->addItem(tr("All terms"));
@@ -72,6 +74,7 @@ void UIPrefsDialog::init()
 
     connect(stylesheetPB, SIGNAL(clicked()),this, SLOT(showStylesheetDialog()));
     connect(resetSSPB, SIGNAL(clicked()), this, SLOT(resetStylesheet()));
+    connect(darkSSPB, SIGNAL(clicked()), this, SLOT(setDarkMode()));
     connect(snipCssPB, SIGNAL(clicked()),this, SLOT(showSnipCssDialog()));
     connect(synFilePB, SIGNAL(clicked()),this, SLOT(showSynFileDialog()));
     connect(resetSnipCssPB, SIGNAL(clicked()), this, SLOT(resetSnipCss()));
@@ -98,6 +101,11 @@ void UIPrefsDialog::init()
             replAbsCB, SLOT(setEnabled(bool)));
     connect(ssNoCompleteCB, SIGNAL(toggled(bool)), 
             ssSearchOnCompleteCB, SLOT(setDisabled(bool)));
+    connect(resetscPB, SIGNAL(clicked()), this, SLOT(resetShortcuts()));
+
+    (void)new HelpClient(this);
+    HelpClient::installMap("sctab", "RCL.SEARCH.GUI.SHORTCUTS");
+    
     setFromPrefs();
 }
 
@@ -149,6 +157,12 @@ void UIPrefsDialog::setFromPrefs()
     noStatusBarCB->setChecked(prefs.noStatusBar);
     noMenuBarCB->setChecked(prefs.noMenuBar);
     noSSTypCMBCB->setChecked(prefs.noSSTypCMB);
+    restabShowTxtNoShiftRB->setChecked(prefs.resTableTextNoShift);
+    restabShowTxtShiftRB->setChecked(!prefs.resTableTextNoShift);
+    resTableNoHoverMetaCB->setChecked(prefs.resTableNoHoverMeta);
+    noResTableHeaderCB->setChecked(prefs.noResTableHeader);
+    showResTableVHeaderCB->setChecked(prefs.showResTableVHeader);
+    noRowJumpShortcutsCB->setChecked(prefs.noResTableRowJumpSC);
     showTrayIconCB->setChecked(prefs.showTrayIcon);
     if (!prefs.showTrayIcon) {
         prefs.closeToTray = false;
@@ -177,10 +191,17 @@ void UIPrefsDialog::setFromPrefs()
         break;
     }
     // Query terms color
-    qtermStyleLE->setText(prefs.qtermstyle);
+    qtermStyleCMB->setCurrentText(prefs.qtermstyle);
+    if (qtermStyleCMB->count() <=1) {
+        qtermStyleCMB->addItem(prefs.qtermstyle);
+        qtermStyleCMB->addItem("color: blue");
+        qtermStyleCMB->addItem("color: red;background: yellow");
+        qtermStyleCMB->addItem(
+            "color: #dddddd; background: black; font-weight: bold");
+    }    
     // Abstract snippet separator string
     abssepLE->setText(prefs.abssep);
-    dateformatLE->setText(prefs.reslistdateformat);
+    dateformatLE->setText(u8s2qs(prefs.reslistdateformat));
 
     // Result list font family and size
     reslistFontFamily = prefs.reslistfontfamily;
@@ -195,6 +216,7 @@ void UIPrefsDialog::setFromPrefs()
         string nm = path_getsimple(qs2path(qssFile));
         stylesheetPB->setText(path2qs(nm));
     }
+    darkMode = prefs.darkMode;
 
     snipCssFile = prefs.snipCssFile;
     if (snipCssFile.isEmpty()) {
@@ -269,6 +291,63 @@ void UIPrefsDialog::setFromPrefs()
         }
     }
     idxLV->sortItems();
+    readShortcuts();
+    setSSButState();
+}
+
+void UIPrefsDialog::readShortcutsInternal(const QStringList& sl)
+{
+    shortcutsTB->setRowCount(0);
+    shortcutsTB->setColumnCount(4);
+    shortcutsTB->setHorizontalHeaderItem(
+        0, new QTableWidgetItem(tr("Context")));
+    shortcutsTB->setHorizontalHeaderItem(
+        1, new QTableWidgetItem(tr("Description")));
+    shortcutsTB->setHorizontalHeaderItem(
+        2, new QTableWidgetItem(tr("Shortcut")));
+    shortcutsTB->setHorizontalHeaderItem(
+        3, new QTableWidgetItem(tr("Default")));
+    int row = 0;
+    m_scids.clear();
+    for (int i = 0; i < sl.size();) {
+        LOGDEB0("UIPrefsDialog::readShortcuts: inserting row " <<
+                qs2utf8s(sl.at(i)) << " " << qs2utf8s(sl.at(i+1)) << " " <<
+                qs2utf8s(sl.at(i+2)) << " " << qs2utf8s(sl.at(i+3)) << "\n");
+        shortcutsTB->insertRow(row);
+        m_scids.push_back(sl.at(i++));
+        shortcutsTB->setItem(row, 0, new QTableWidgetItem(sl.at(i++)));
+        shortcutsTB->setItem(row, 1, new QTableWidgetItem(sl.at(i++)));
+        auto ed = new QKeySequenceEdit(QKeySequence(sl.at(i++)));
+        shortcutsTB->setCellWidget(row, 2, ed);
+        shortcutsTB->setItem(row, 3, new QTableWidgetItem(sl.at(i++)));
+        row++;
+    }
+    shortcutsTB->resizeColumnsToContents();
+    shortcutsTB->horizontalHeader()->setStretchLastSection(true);
+}
+
+void UIPrefsDialog::readShortcuts()
+{
+    readShortcutsInternal(SCBase::scBase().getAll());
+}
+
+void UIPrefsDialog::resetShortcuts()
+{
+    readShortcutsInternal(SCBase::scBase().getAllDefaults());
+}
+
+void UIPrefsDialog::storeShortcuts()
+{
+    SCBase& scbase = SCBase::scBase();
+    QStringList slout;
+    for (int row = 0; row < shortcutsTB->rowCount(); row++) {
+        QString dflt = shortcutsTB->item(row, 0)->text();
+        QString ctxt = shortcutsTB->item(row, 1)->text();
+        auto qsce = (QKeySequenceEdit*)(shortcutsTB->cellWidget(row, 2));
+        QString val = qsce->keySequence().toString();
+        scbase.set(m_scids[row], dflt, ctxt, val);
+    }
+    scbase.store();
 }
 
 void UIPrefsDialog::setupReslistFontPB()
@@ -314,13 +393,14 @@ void UIPrefsDialog::accept()
     prefs.collapseDuplicates = collapseDupsCB->isChecked();
     prefs.maxhltextkbs = maxHLTSB->value();
 
-    prefs.qtermstyle = qtermStyleLE->text();
+    prefs.qtermstyle = qtermStyleCMB->currentText();
     prefs.abssep = abssepLE->text();
-    prefs.reslistdateformat = dateformatLE->text();
-    prefs.creslistdateformat = (const char*)prefs.reslistdateformat.toUtf8();
+    prefs.reslistdateformat = qs2utf8s(dateformatLE->text());
 
     prefs.reslistfontfamily = reslistFontFamily;
     prefs.reslistfontsize = reslistFontSize;
+    prefs.darkMode = darkMode;
+    prefs.setupDarkCSS();
     prefs.qssFile = qssFile;
     QTimer::singleShot(0, m_mainWindow, SLOT(applyStyleSheet()));
     prefs.snipCssFile = snipCssFile;
@@ -357,6 +437,11 @@ void UIPrefsDialog::accept()
     prefs.noMenuBar = noMenuBarCB->isChecked();
     m_mainWindow->setupMenus();
     prefs.noSSTypCMB = noSSTypCMBCB->isChecked();
+    prefs.resTableTextNoShift = restabShowTxtNoShiftRB->isChecked();
+    prefs.resTableNoHoverMeta = resTableNoHoverMetaCB->isChecked();
+    prefs.noResTableHeader = noResTableHeaderCB->isChecked();
+    prefs.showResTableVHeader = showResTableVHeaderCB->isChecked();
+    prefs.noResTableRowJumpSC = noRowJumpShortcutsCB->isChecked();
     prefs.noStatusBar = noStatusBarCB->isChecked();
     m_mainWindow->setupStatusBar();
     prefs.noClearSearch = noClearSearchCB->isChecked();
@@ -401,6 +486,8 @@ void UIPrefsDialog::accept()
     }
 
     rwSettings(true);
+    storeShortcuts();
+    
     string reason;
     maybeOpenDb(reason, true);
     emit uiprefsDone();
@@ -475,26 +562,40 @@ void UIPrefsDialog::showFontDialog()
     }
 }
 
-void UIPrefsDialog::showStylesheetDialog()
+void UIPrefsDialog::setSSButState()
 {
-    qssFile = myGetFileName(false, "Select stylesheet file", true);
-    string nm = path_getsimple(qs2path(qssFile));
-    if (!nm.empty()) {
-        stylesheetPB->setText(path2qs(nm));
+    darkSSPB->setEnabled(!darkMode);
+    resetSSPB->setEnabled(darkMode || !qssFile.isEmpty());
+    if (darkMode || qssFile.isEmpty()) {
+        stylesheetPB->setText(tr("Choose QSS File"));
     } else {
-        stylesheetPB->setText(tr("Choose"));
+        stylesheetPB->setText(path2qs(path_getsimple(qs2path(qssFile))));
     }
 }
 
-void UIPrefsDialog::resetStylesheet(QString fn)
+void UIPrefsDialog::showStylesheetDialog()
 {
-    qssFile = fn;
-    if (fn.isEmpty()) {
-        stylesheetPB->setText(tr("Choose"));
-    } else {
-        stylesheetPB->setText(fn);
+    auto newfn = myGetFileName(false, "Select stylesheet file", true);
+    if (!newfn.isEmpty()) {
+        qssFile = newfn;
+        darkMode = false;
     }
+    setSSButState();
 }
+void UIPrefsDialog::setDarkMode()
+{
+    auto fn = path_cat(path_cat(theconfig->getDatadir(), "examples"), "recoll-dark.qss");
+    qssFile = u8s2qs(fn);
+    darkMode = true;
+    setSSButState();
+}
+void UIPrefsDialog::resetStylesheet()
+{
+    qssFile.clear();
+    darkMode = false;
+    setSSButState();
+}
+
 void UIPrefsDialog::showSnipCssDialog()
 {
     snipCssFile = myGetFileName(false, "Select snippets window CSS file", true);
@@ -528,13 +629,13 @@ void UIPrefsDialog::showSynFileDialog()
 void UIPrefsDialog::resetReslistFont()
 {
     reslistFontFamily = "";
-    reslistFontSize = 0;
+    reslistFontSize = QFont().pointSize();
     setupReslistFontPB();
 }
 
 void UIPrefsDialog::showViewAction()
 {
-    if (m_viewAction== 0) {
+    if (m_viewAction == 0) {
         m_viewAction = new ViewAction(0);
     } else {
         // Close and reopen, in hope that makes us visible...
