@@ -21,6 +21,9 @@
 
 #include "ui_uiprefs.h"
 
+#include <vector>
+#include <QString>
+
 class QDialog;
 class ViewAction;
 class RclMain;
@@ -37,22 +40,17 @@ public:
     }
     ~UIPrefsDialog(){};
 
-    QString reslistFontFamily;
-    int reslistFontSize;
-    QString qssFile;
-    QString snipCssFile;
-    QString synFile;
-
     virtual void init();
     void setFromPrefs();
-
+                           
 public slots:
     virtual void showFontDialog();
     virtual void resetReslistFont();
     virtual void showStylesheetDialog();
+    virtual void resetStylesheet();
+    virtual void setDarkMode();
     virtual void showSynFileDialog();
     virtual void showSnipCssDialog();
-    virtual void resetStylesheet(QString fn = QString());
     virtual void resetSnipCss();
     virtual void showViewAction();
     virtual void showViewAction(const QString& mt);
@@ -67,6 +65,7 @@ public slots:
     virtual void editHeaderText();
     virtual void extradDbSelectChanged();
     virtual void extraDbEditPtrans();
+    virtual void resetShortcuts();
     
 signals:
     void uiprefsDone();
@@ -76,11 +75,25 @@ protected slots:
     virtual void reject();
 private:
     void setupReslistFontPB();
-    // Locally stored data (pending ok/cancel)
+    void readShortcuts();
+    void storeShortcuts();
+    void readShortcutsInternal(const QStringList&);
+    void setSSButState();
+    
+    ViewAction *m_viewAction{nullptr};
+    RclMain *m_mainWindow;
+
+    // Locally stored data (pending ok/cancel), for the parameters for
+    // which our UI state is not enough.
     QString paraFormat;
     QString headerText;
-    ViewAction *m_viewAction;
-    RclMain *m_mainWindow;
+    std::vector<QString> m_scids;
+    QString reslistFontFamily;
+    int reslistFontSize;
+    QString qssFile;
+    bool darkMode{false};
+    QString snipCssFile;
+    QString synFile;
 };
 
 #endif /* _UIPREFS_W_H_INCLUDED_ */
