@@ -1721,7 +1721,7 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi, Doc &doc)
         // won't work).
         time_t mtime = atoll(doc.dmtime.empty() ? doc.fmtime.c_str() : 
                              doc.dmtime.c_str());
-        struct tm tmb{0,0,0,0,0,0,0,0,0};
+        struct tm tmb;
         localtime_r(&mtime, &tmb);
         char buf[50]; // It's actually 9, but use 50 to suppress warnings.
         snprintf(buf, 50, "%04d%02d%02d",
@@ -1845,10 +1845,8 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi, Doc &doc)
         // purposes.
         const string *fnp = 0;
         if (!doc.peekmeta(Rcl::Doc::keyfn, &fnp) || fnp->empty()) {
-            if (doc.peekmeta(Rcl::Doc::keytcfn, &fnp) && !fnp->empty()) {
-                string value = 
-                    neutchars(truncate_to_word(*fnp, 
-                                               m_idxMetaStoredLen), cstr_nc);
+            if (doc.peekmeta(Rcl::Doc::keyctfn, &fnp) && !fnp->empty()) {
+                string value = neutchars(truncate_to_word(*fnp, m_idxMetaStoredLen), cstr_nc);
                 RECORD_APPEND(record, Rcl::Doc::keyfn, value);
             }
         }
@@ -2403,7 +2401,7 @@ bool Db::dbStats(DbStats& res, bool listfailed)
             try {
                 Xapian::Document doc = xdb.get_document(docid);
                 string sig = doc.get_value(VALUE_SIG);
-                if (sig.empty() || sig[sig.size()-1] != '+') {
+                if (sig.empty() || sig.back() != '+') {
                     continue;
                 }
                 string data = doc.get_data();
