@@ -1021,7 +1021,8 @@ bool ExecCmd::maybereap(int *status)
         e.inactivate();
         return false;
     } else {
-        LOGDEB("ExecCmd::maybereap: got status 0x" << (status) << "\n");
+        if (*status)
+            LOGDEB("ExecCmd::maybereap: got status 0x" << *status << "\n");
         m->m_pid = -1;
         return true;
     }
@@ -1063,7 +1064,7 @@ void ReExec::init(int argc, char *args[])
 
 void ReExec::insertArgs(const vector<string>& args, int idx)
 {
-    vector<string>::iterator it, cit;
+    vector<string>::iterator it;
     unsigned int cmpoffset = (unsigned int) - 1;
 
     if (idx == -1 || string::size_type(idx) >= m_argv.size()) {
