@@ -33,6 +33,9 @@ extern std::string path_defaultrecollconfsubdir();
 // Check if path is either non-existing or an empty directory.
 extern bool path_empty(const std::string& path);
 
+/// Where we create the user data subdirs
+extern std::string path_homedata();
+
 /// e.g. /usr/share/recoll. Depends on OS and config
 extern const std::string& path_pkgdatadir();
 
@@ -115,5 +118,15 @@ extern bool thumbPathForUrl(const std::string& url, int size,
 // string data (to pass to other thread):
 template <class T> void map_ss_cp_noshr(T s, T *d);
 
+// Set or extend metadata field. We store the data as CSV
+template <class T> void addmeta(T& store, const std::string& nm,
+                                const std::string& value);
+
+// Compare charset names, removing the more common spelling variations
+extern bool samecharset(const std::string& cs1, const std::string& cs2);
+// Divine language from locale
+extern std::string localelang();
+// Divine 8bit charset from language
+extern std::string langtocode(const std::string& lang);
 
 #endif /* _RCLUTIL_H_INCLUDED_ */
