@@ -16,10 +16,9 @@
  */
 #ifndef _TRANSCODE_H_INCLUDED_
 #define _TRANSCODE_H_INCLUDED_
-/** 
- * 
- */
+
 #include <string>
+
 /**
  * c++ized interface to iconv
  *
@@ -32,13 +31,8 @@
  *     errors like unknown charset names
  */
 extern bool transcode(const std::string &in, std::string &out, 
-		      const std::string &icode,
-		      const std::string &ocode, 
-		      int *ecnt = 0);
-
-#ifdef _WIN32
-extern bool wchartoutf8(const wchar_t *in, std::string& out);
-extern bool utf8towchar(const std::string& in, wchar_t *out, size_t obytescap);
-#endif
+              const std::string &icode,
+              const std::string &ocode, 
+              int *ecnt = 0);
 
 #endif /* _TRANSCODE_H_INCLUDED_ */
